<?php

/*
*
*   Title Polish
*   A Plugin for MyBB to normalize and proper-case thread / post titles which are mixed-cased. 
*   effone @ demonate.com
*
*
*/

// Disallow direct access to this file
if(!defined("IN_MYBB")){
	die("Don't be smart, use links in page.");
}

// Basic Informations about the plugin
function titlepolish_info(){
	return array(
		'name'			=> 'Title Polish',
		'description'	=> 'Normalize and proper-case thread / post titles which are mixed-cased.',
		'website'		=> 'http://demonate.com',
		'author'		=> 'effone',
		'authorsite'	=> 'http://effone.in',
		'version'		=> '0.1',
		'guid' 			=> 'bd2129da7798cd825a4bb06118904b6b',
		'compatibility' => '16*'
	);
}

// Hooks :o
$plugins->add_hook('datahandler_post_validate_thread', 'titlepolish_normalize');

function titlepolish_normalize($pin){
	global $db, $mybb;
	$post = &$pin->data;

	$escape = $mybb->settings['titlepolish_escape']; // The escape key
	$proof = explode(",",$mybb->settings['titlepolish_forum']); // The omitted forum IDs

//-----------------------------------------//

	if ($mybb->settings['titlepolish_active'] && !in_array(intval($post['fid']), $proof)){
		$c = strlen($escape); // Measure the escape key length

		if ($escape == substr($post['subject'],0,$c)){ // Check whether subject contains escape key in the beginning.
			$post['subject'] = substr($post['subject'],$c); // If yes, remove the escape key and return the subject as is.
		} else {
			$post['subject'] = ucwords(strtolower($post['subject'])); // If no, normalize subject.
		}
		unset($escape, $proof, $c); // Destroy the references no longer required.
	}
}

// Plugin activation routine
function titlepolish_activate(){
	global $db, $mybb;
	
	// Build the ACP Settings for Title Polish
	
	$titlepolish_group = array(
		"name"			=> "titlepolish",
		"title"			=> "Title Polish",
		"description"	=> "Normalize and proper-case thread / post titles which are mixed-cased.",
		"disporder"		=> "3",
		"isdefault"		=> "0"
	);	
	$db->insert_query("settinggroups", $titlepolish_group);
	$gid = $db->insert_id();
	
	$titlepolish[] = array(
		"name"			=> 'titlepolish_active',
		"title"			=> 'Activate Title Polish?',
		"description"	=> 'Switch to activate or deactivate the plugin.',
		"optionscode" 	=> "onoff",
		"value"			=> '1',
		"disporder"		=> '1',
		"gid"			=> intval($gid),
	);
	
	$titlepolish[] = array(
		"name"			=> 'titlepolish_escape',
		"title"			=> 'Escape Key',
		"description"	=> 'Set an escape key, using which in front of the title the polish will not happen. Try to set some unique key.',
		"optionscode" 	=> "text",
		"value"			=> '`',
		"disporder"		=> '2',
		"gid"			=> intval($gid),
	);
	
	$titlepolish[] = array(
		"name"			=> 'titlepolish_forum',
		"title"			=> 'Bypass Forums',
		"description"	=> 'Set the forum ids (fid) where this plugin will not affect, separated by comma (,).',
		"optionscode" 	=> "text",
		"value"			=> '',
		"disporder"		=> '3',
		"gid"			=> intval($gid),
	);
	
	foreach($titlepolish as $t_polopts)
	{
		$db->insert_query("settings", $t_polopts);
	}
	
	rebuild_settings();
 }

// Plugin deactivation routine
function titlepolish_deactivate(){
	global $db, $mybb;
	
	$db->delete_query("settings", "name IN ('titlepolish_active', 'titlepolish_escape', 'titlepolish_forum')");
	$db->delete_query("settinggroups", "name='titlepolish'");
	
	rebuild_settings();
}

?>